# Release history (latest release first)

## Version 0.1.1 (June 28, 2024)
- Bug fixes and minor improvements to code (no updates to SQLite file)

## Version 0.1.0 (May 31, 2024)

- Data from 2024 _Review of Particle Physics_
- First production version
- Minor bug fixes and documentation updates

## Version 0.0.7 (May 28, 2024)

- Revised database schema (version 0.2) with new `pdgitem`, `pdgitem_map` and `pdgdecay` tables
- Support for decays
- Bug fixes (especially also in metadata)
- Final beta version for 2023 _Review of Particle Physics_

## Version 0.0.6 (Dec 14, 2023)

- Support for widths and lifetimes
- Bug fixes (especially also in metadata)

## Version 0.0.5 (May 31, 2023)

- First public beta version
- Data from 2023 update of _Review of Particle Physics_
